@@ -22,50 +22,61 @@ Examples:
 
     >>> predictions = predictit.main.predict()
 
+To see all the possible values, use
+
+    >>> predictit.config.print_config()
+
 '''
 
 import predictit
 
 
-import numpy as np
 
+import numpy as np
 
 config = {
 
-    # Edit presets as you need but beware - it will overwrite normal config. Default presets edit for example number of used models, number of lengths, n_steps_in.
+    # Edit presets as you need but beware - it will overwrite normal config. Default presets edit for example
+    # number of used models, number of lengths, n_steps_in.
 
-    'used_function': 'predict_multiple',  # If running main.py script, execute function. Choices: 'predict', 'predict_multiple' or 'compare_models'. If import as library, ignore - just use function.
+    'used_function': 'compare_models',  # If running main.py script, execute function. Choices: 'predict', 'predict_multiple' or 'compare_models'. If import as library, ignore - just use function.
 
     'use_config_preset': 'none',  # 'fast', 'normal' or 'none'. Edit some selected config, other remains the same, check config_presets.py file.
 
     # Input settings
 
-    'data': np.random.randn(100, 100),  # Use numpy array, or pandas dataframe. This will overwrite data_source. If you use csv, set up to None.
-    'data_all': None,  # Just for compare_models function. Dictionary of data names and it's values or list of data parts.
+    'data': None,  # Use numpy array, or pandas dataframe. This will overwrite data_source. If you use csv, set up to None. Data shape is (n_samples, n_feature)
+                   # - that means rows are samples and columns are features.
+    'data_all': [np.array(range(1000))],#None,  # Just for compare_models function. Dictionary of data names and list of it's values and predicted columns or list of data parts.
+    # data_all examples: {'data_1': [my_dataframe, 'column_name']} or [my_data[-2000:], my_data[-1000:]] and 'predicted_column' from config as column name.
 
-    'data_source': 'test',  # Data source. ('csv' or 'sql' or 'test') - If sql, you have to edit the query to fit your database.
+    'data_source': 'test',  # Data source. ('csv', 'txt', 'sql' or 'test') - If sql, you have to edit the query to fit your database.
 
     'csv_full_path': r'',  # Full CSV path with suffix.
-    'csv_test_data_relative_path': '',  # CSV name with suffix in test_data folder (5000 Sales Records.csv or daily-minimum-temperatures.csv) !!! Turn it off if not testing to not break csv full path !!! Test data are gitignored... use your own.
+    'csv_test_data_relative_path': '',  # CSV name with suffix in test_data folder (5000 Sales Records.csv or daily-minimum-temperatures.csv)
+                                        # !!! Turn it off if not testing to not break csv full path !!! Test data are gitignored... use your own.
 
-    'predicted_column': 'CO (ppm)',  # Name of predicted column (for dataframe data) or it's index - string or int.
-    'predicted_columns': ['*'],  # For predict_multiple function only! List of names of predicted columns or it's indexes. If 'data' is dataframe or numpy, then you can use '*' to predict all the columns.
+    'predicted_column': '',  # Name of predicted column (for dataframe data) or it's index - string or int.
+    'predicted_columns': [],  # For predict_multiple function only! List of names of predicted columns or it's indexes. If 'data' is dataframe or numpy, then you can use '*' to predict all the columns.
 
     'freq': 0,  # Interval for predictions 'M' - months, 'D' - Days, 'H' - Hours.
     'freqs': [],  # For predict_multiple function only! List of intervals of predictions 'M' - months, 'D' - Days, 'H' - Hours. Default use [].
 
-    'datetime_index': 'čas',  # Index of dataframe datetime column or it's name if it has datetime column. If there already is index in input data, it will be used automatically. Data are sorted by time.
+    'datetime_index': '',  # Index of dataframe datetime column or it's name if it has datetime column. If there already is index in input data, it will be used automatically. Data are sorted by time.
 
-    'datalength': 2000,  # The length of the data used for prediction. If 0, than full length.
+    'datalength': 0,  # The length of the data used for prediction (after resampling). If 0, than full length.
+    'max_imported_length': 0,  # Max length of imported samples (before resampling). If 0, than full length.
 
     # Output settings
 
     'predicts': 7,  # Number of predicted values - 7 by default.
 
-    'mode': 'predict',  # If 'validate', put apart last few values (defined py by 'predict') and evaluate on test data that was not in train set.
+    'mode': 'predict',  # If 'validate', put apart last few ('predicts' + 'validation_gap') values and evaluate on test data that was not in train set. Do not setup - use compare_models function, it will use it automattically.
     'validation_gap': 10,  # If 'mode' == 'validate', then describe how many samples are between train and test set. The bigger gap is, the bigger knowledge generalization is necesssary.
-    'return_type': 'best',  # 'best', 'all', 'dict', 'models_error_criterion' or 'detailed_results_dictionary'. 'best' return array of predictions, 'all' return more models (config.compareit) results sorted by how efficient they are. 'results dataframe' return results and models names in columns.
-                            # 'detailed_results_dictionary' is used for GUI and return results as best result, all results, string div with plot and more. 'models_error_criterion' returns MAPE, RMSE (based on config) or dynamic warping criterion of all models in array.
+    'return_type': 'best',  # 'best', 'all', 'dict', 'models_error_criterion' or 'detailed_results_dictionary'. 'best' return array of predictions, 'all' return more models (config.compareit)
+                            # results sorted by how efficient they are. 'results dataframe' return results and models names in columns. 'detailed_results_dictionary' is used for GUI
+                            # and return results as best result, all results, string div with plot and more. 'models_error_criterion' returns MAPE,
+                            # RMSE (based on config) or dynamic warping criterion of all models in array.
     'debug': 1,  # Debug - If 1, print all results and all the warnings and errors on the wignoreday, if 2, stop on all warnings.
 
     'plot': 1,  # If 1, plot interactive graph.
@@ -74,8 +85,8 @@ config = {
     'save_plot': 0,  # (bool) - Html if plotly type, png if matplotlibtype.
     'save_plot_path': '',  # Path where to save the plot (String), if empty string or 0 - saved to desktop.
     'plot_name': 'Predictions',
-    'plot_history_length': 300,  # How many historic values will be plotted
-    'plot_number_of_models': 6,  # confiNumber of plotted models. If none or 0, than all models will be evaluated. 1 if only the best one.
+    'plot_history_length': 100,  # How many historic values will be plotted
+    'plot_number_of_models': 12,  # confiNumber of plotted models. If none or 0, than all models will be evaluated. 1 if only the best one.
 
     'print': 1,  # Turn on and off all printed details at once.
     'print_table': 1,  # Whether print table with models errors and time to compute.
@@ -86,7 +97,7 @@ config = {
 
     # Prediction parameters settings
 
-    'default_n_steps_in': 15,  # How many lagged values are in vector input to model.
+    'default_n_steps_in': 30,  # How many lagged values are in vector input to model.
     'other_columns': 1,  # If use other columns. Bool.
     'default_other_columns_length': 2,  # Other columns vector length used for predictions. If None, lengths same as predicted columnd. If 0, other columns are not used for prediction.
     'remove_nans': 'any_columns',  # 'any_columns' will remove all the columns where is at least one nan column.
@@ -96,18 +107,20 @@ config = {
 
     'data_transform': 0,  # 'difference' or 0 - Transform the data on differences between two neighbor values.
     'analyzeit': 0,  # Analyze input data - Statistical distribution, autocorrelation, seasonal decomposition etc. If 1, analyze original data, if 2 analyze preprocessed data, if 3, then both.
+    'analyze_seasonal_decompose': {'period': 365, 'model': 'additive'},  # Parameters for seasonal decompose in analyze. Find if there are periodically repeating patterns in data.
     'standardize': 'standardize',  # One from None, 'standardize', '-11', '01', 'robust'.
 
     'optimizeit': 0,  # Find optimal parameters of models.
     'optimizeit_details': 2,  # 1 print best parameters of models, 2 print every new best parameters achieved, 3 prints all results.
     'optimizeit_limit': 1,  # How many seconds can take one model optimization.
 
+    'smooth': (11, 2),  # Smoothing data with Savitzky-Golay filter. First argument is window and second is polynomial order. If 0, not smoothing.
     'power_transformed': 0,  # Whether transform results to have same standard deviation and mean as train data. 0 no power transform, 1 on output and 2 on output and before evaluating.
-    'remove_outliers': 0,  # Remove extraordinary values. Value is threshold for ignored values. Value means how many times standard deviation from the average threshold is far (have to be > 3, else delete most).
+    'remove_outliers': 0,  # Remove extraordinary values. Value is threshold for ignored values. Value means how many times standard deviation from the average threshold is far (have to be > 3, else delete most of data). If predicting anomalies, use 0.
     'error_criterion': 'mape',  # 'mape' or 'rmse' or 'dtw' (dynamic time warping).
     'last_row': 0,  # If 0, erase last row (for example in day frequency, day is not complete yet).
     'correlation_threshold': 0.5,  # If evaluating from more collumns, use only collumns that are correlated. From 0 (All columns included) to 1 (only column itself).Z
-    'confidence_interval': 0,  # Area of confidence in result plot (grey area where we suppose values) - Bigger value, narrower area - maximum 1.
+    'confidence_interval': 0.8,  # Area of confidence in result plot (grey area where we suppose values) - Bigger value, narrower area - maximum 1. If 0 - not plotted.
     'already_trained': 0,  # Computationaly hard models (LSTM) load from disk.
     #'plotallmodels': 0,  # Plot all models (recommended only in interactive jupyter window).
 
@@ -139,8 +152,8 @@ config = {
         # 'tensorflow_lstm': predictit.models.tensorflow,
         # 'tensorflow_mlp': predictit.models.tensorflow,
 
-        **{model_name: predictit.models.sklearn_regression for model_name in [  # 'Extra trees regression', 'Random forest regression', 'Bagging regression'
-            'Sklearn regression', 'Bayes ridge regression', 'Hubber regression', 'Decision tree regression',
+        **{model_name: predictit.models.sklearn_regression for model_name in [  # 'Extra trees regression', 'Random forest regression', 'Bagging regression', 'Hubber regression'
+            'Sklearn regression', 'Bayes ridge regression', 'Decision tree regression',
             'KNeighbors regression', 'Stochastic gradient regression',
             'Passive aggressive regression', 'Extreme learning machine', 'Gen Extreme learning machine', 'Gradient boosting']},
 
@@ -208,7 +221,8 @@ config.update({
                                       ['dense', {'units': 7, 'activation': 'relu'}]],
                            'epochs': 100, 'already_trained': 0, 'save': 1, 'saved_model_path_string': 'stored_models', 'optimizer': 'adam', 'loss': 'mse', 'verbose': 0, 'metrics': 'accuracy', 'timedistributed': 0},
 
-        'Sklearn regression': {'regressor': 'linear', 'alpha': 0.0001, 'n_iter': 100, 'epsilon': 1.35, 'alphas': [0.1, 0.5, 1], 'gcv_mode': 'auto', 'solver': 'auto', 'alpha_1': 1.e-6, 'alpha_2': 1.e-6, 'lambda_1': 1.e-6, 'lambda_2': 1.e-6, 'n_hidden': 20, 'rbf_width': 0, 'activation_func': 'selu'},
+        'Sklearn regression': {'regressor': 'linear', 'alpha': 0.0001, 'n_iter': 100, 'epsilon': 1.35, 'alphas': [0.1, 0.5, 1], 'gcv_mode': 'auto', 'solver': 'auto', 'alpha_1': 1.e-6,
+                               'alpha_2': 1.e-6, 'lambda_1': 1.e-6, 'lambda_2': 1.e-6, 'n_hidden': 20, 'rbf_width': 0, 'activation_func': 'selu'},
         'Bayes ridge regression': {'regressor': 'bayesianridge', 'n_iter': 300, 'alpha_1': 1.e-6, 'alpha_2': 1.e-6, 'lambda_1': 1.e-6, 'lambda_2': 1.e-6},
         'Hubber regression': {'regressor': 'huber', 'epsilon': 1.35, 'alpha': 0.0001},
         'Extra trees regression': {'regressor': 'Extra trees'},
@@ -259,14 +273,17 @@ def update_references_2():
 
             'ARMA': {'p': [1, config['maxorder']], 'q': config['order'], 'trend': ['c', 'nc']},
             'ARIMA (Autoregression integrated moving average)': {'p': [1, config['maxorder']], 'd': [0, 2], 'q': [0, 4], 'trend': ['c', 'nc']},
-            # 'SARIMAX (Seasonal ARIMA)': {'p': [1, config['maxorder']], 'd': config['order'], 'q': config['order'], 'pp': config['order'], 'dd': config['order'], 'qq': config['order'], 'season': config['order'], 'method': ['lbfgs', 'bfgs', 'newton', 'nm', 'cg', 'ncg', 'powell'], 'trend': ['n', 'c', 't', 'ct'], 'enforce_invertibility': [True, False], 'enforce_stationarity': [True, False], 'forecast_type': ['in_sample', 'out_of_sample']},
+            # 'SARIMAX (Seasonal ARIMA)': {'p': [1, config['maxorder']], 'd': config['order'], 'q': config['order'], 'pp': config['order'], 'dd': config['order'], 'qq': config['order'],
+            # 'season': config['order'], 'method': ['lbfgs', 'bfgs', 'newton', 'nm', 'cg', 'ncg', 'powell'], 'trend': ['n', 'c', 't', 'ct'], 'enforce_invertibility': [True, False], 'enforce_stationarity': [True, False], 'forecast_type': ['in_sample', 'out_of_sample']},
 
             # 'Autoregressive Linear neural unit': {'mi': [1e-8, 10.0], 'minormit': [0, 1], 'damping': [0.0, 100.0]},
             # 'Linear neural unit with weigths predict': {'mi': [1e-8, 10.0], 'minormit': [0, 1], 'damping': [0.0, 100.0]},
             # 'Conjugate gradient': {'epochs': config['epochs']},
 
-            ### 'tensorflow_lstm': {'loses':["mean_squared_error", "mean_absolute_error", "mean_absolute_percentage_error", "mean_squared_logarithmic_error", "squared_hinge", "logcosh", "kullback_leibler_divergence"], 'activations':['softmax', 'elu', 'selu', 'softplus', 'tanh', 'sigmoid', 'exponential', 'linear']},
-            ### 'tensorflow_mlp': {'loses':["mean_squared_error", "mean_absolute_error", "mean_absolute_percentage_error", "mean_squared_logarithmic_error", "squared_hinge", "logcosh", "kullback_leibler_divergence"], 'activations':['softmax', 'elu', 'selu', 'softplus', 'tanh', 'sigmoid', 'exponential', 'linear']},
+            ### 'tensorflow_lstm': {'loses':["mean_squared_error", "mean_absolute_error", "mean_absolute_percentage_error", "mean_squared_logarithmic_error", "squared_hinge", "logcosh",
+            ### "kullback_leibler_divergence"], 'activations':['softmax', 'elu', 'selu', 'softplus', 'tanh', 'sigmoid', 'exponential', 'linear']},
+            ### 'tensorflow_mlp': {'loses':["mean_squared_error", "mean_absolute_error", "mean_absolute_percentage_error", "mean_squared_logarithmic_error", "squared_hinge", "logcosh",
+            ### "kullback_leibler_divergence"], 'activations':['softmax', 'elu', 'selu', 'softplus', 'tanh', 'sigmoid', 'exponential', 'linear']},
 
             'Sklearn regression': {'regressor': config['regressors']},  # 'alpha': config['alpha'], 'n_iter': [100, 500], 'epsilon': [1.01, 5.0], 'alphas': [[0.1, 0.1, 0.1], [0.5, 0.5, 0.5], [0.9, 0.9, 0.9]], 'gcv_mode': ['auto', 'svd', 'eigen'], 'solver': ['auto', 'svd', 'eigen']},
             'Extra trees': {'n_estimators': [1., 500.]},
@@ -290,7 +307,8 @@ config.update({
                          "unclosed file <_io.TextIOWrapper name",
                          "Mean of empty slice",
                          "Check mle_retvals",
-                         "The default value of n_estimators will change"],
+                         "The default value of n_estimators will change",
+                         "statsmodels.tsa.AR has been deprecated "],
 
 
     # If SQL, sql credentials
@@ -359,3 +377,11 @@ update_references_1()
 update_references_2()
 
 config_check_set = set(config.keys())
+
+
+def print_config():
+    import pygments
+
+    from pathlib import Path
+    with open(Path(__file__).resolve(), "r") as f:
+        print(pygments.highlight("\n".join(f.readlines()), pygments.lexers.python.PythonLexer(), pygments.formatters.Terminal256Formatter(style='friendly')))
