@@ -1,19 +1,157 @@
-"""Module for data preprocessing. Contain functions for removing outliers, NaN columns or
-function for making inputs and outputs from time series if you want to see how functions work -
+"""Module for data preprocessing. Contain functions for removing outliers,
+NaN columns or data smoothing. If you want to see how functions work -
 working examples with printed results are in tests - visual.py.
 
-Default output data shape is (n_features, n_sample) !!! Its different than usual convention...
+Default output data shape is (n_samples, n_features)
+
+All processing funtions after data_consolidation use numpy.ndarray with ndim == 2,
+so reshape(1, -1) if necessary.
+
 """
 
 import pandas as pd
 import numpy as np
 import scipy
 import warnings
+from sklearn import preprocessing
 
 from predictit.config import config
 from predictit.misc import user_warning, colorize
 
 
+
+def data_consolidation(data):
+    """Input data in various formats and shapes and return data in defined shape,
+    that other functions rely on.
+
+    Args:
+        data (np.ndarray, pd.DataFrame): Input data in well standardized format.
+
+    Raises:
+        KeyError, TypeError: If wrong configuration in config.py.
+            E.g. if predicted column name not found in dataframe.
+
+
+    Returns:
+        np.ndarray, pd.DataFrame, str: Data in standardized form.
+
+        Data array for prediction - predicted column on index 1,
+        and column for ploting as pandas dataframe.
+
+    """
+    ### Pandas dataframe and series ###
+
+    if isinstance(data, pd.Series):
+
+        data = pd.Dataframe(data)
+
+    if isinstance(data, pd.DataFrame):
+        data_for_predictions_df = data
+
+        if isinstance(config['predicted_column'], str):
+
+            predicted_column_name = config['predicted_column']
+
+            try:
+                predicted_column_index = data_for_predictions_df.columns.get_loc(predicted_column_name)
+            except Exception:
+                raise KeyError(colorize(f"Predicted column name - '{config['predicted_column']}' not found in data. Change in config - 'predicted_column'"))
+
+        else:
+            predicted_column_index = config['predicted_column']
+            predicted_column_name = data_for_predictions_df.columns[predicted_column_index]
+
+        try:
+            int(data_for_predictions_df[predicted_column_name].iloc[0])
+        except Exception:
+            user_warning("Predicted column is not number datatype. Setup correct 'predicted_column' in config.py")
+
+        if isinstance(data.index, (pd.core.indexes.datetimes.DatetimeIndex, pd._libs.tslibs.timestamps.Timestamp)):
+            config['datetime_index'] = 'index'
+
+        if config['datetime_index'] is not None:
+
+            if config['datetime_index'] == 'index':
+                pass
+
+            elif isinstance(config['datetime_index'], str):
+                try:
+                    data_for_predictions_df.set_index(config['datetime_index'], drop=True, inplace=True)
+                except Exception:
+                    raise KeyError(colorize(f"Datetime name / index from config - '{config['datetime_index']}' not found in data. Change in config - 'datetime_index'"))
+
+            else:
+                data_for_predictions_df.set_index(data_for_predictions_df.columns[config['datetime_index']], drop=True, inplace=True)
+
+            data_for_predictions_df.index = pd.to_datetime(data_for_predictions_df.index)
+
+            if config['freq']:
+                data_for_predictions_df.sort_index(inplace=True)
+                data_for_predictions_df = data_for_predictions_df.resample(config['freq']).sum()
+                data_for_predictions_df = data_for_predictions_df.asfreq(config['freq'], fill_value=0)
+
+            else:
+
+                data_for_predictions_df.index.freq = pd.infer_freq(data_for_predictions_df.index)
+
+                if data_for_predictions_df.index.freq is None:
+                    user_warning("Datetime index was provided from config, but frequency guess failed. Specify 'freq' in config to resample and have equal sampling.")
+                    data_for_predictions_df.reset_index(inplace=True)
+
+        # Make predicted column index 0
+            data_for_predictions_df.insert(0, predicted_column_name, data_for_predictions_df.pop(predicted_column_name))
+
+        data_for_predictions_df = data_for_predictions_df.iloc[-config['datalength']:, :]
+
+        if config['other_columns']:
+
+            if config['remove_nans'] == 'any_columns':
+                data_for_predictions_df.dropna(how='any', inplace=True, axis=1)
+
+            data_for_predictions_df = data_for_predictions_df.select_dtypes(include='number')
+            data_for_predictions = data_for_predictions_df.values.reshape(-1, 1)
+
+        else:
+            data_for_predictions = data_for_predictions_df[predicted_column_name].values.reshape(-1, 1)
+
+    ### np.ndarray ###
+
+
+    elif isinstance(data, np.ndarray):
+        data_for_predictions = data
+
+        if not isinstance(config['predicted_column'], int):
+            raise TypeError(colorize("'predicted_column' in config is a string and data in numpy array format. Numpy does not allow string assignment"))
+
+        predicted_column_name = 'Predicted column'
+
+        if data_for_predictions.ndim == 1:
+            data_for_predictions = data_for_predictions.reshape(-1, 1)
+
+        if data_for_predictions.shape[0] < data_for_predictions.shape[1]:
+            data_for_predictions = data_for_predictions.T
+
+        data_for_predictions = data_for_predictions[-config['datalength']:, :]
+
+        # Make predicted column on index 0
+        if config['other_columns'] and config['predicted_column'] != 0 and data_for_predictions.shape[1] != 1:
+            data_for_predictions[:, [0, config['predicted_column']]] = data_for_predictions[:, [config['predicted_column'], 0]]
+
+        if not config['other_columns']:
+            data_for_predictions = data_for_predictions[:, 0].reshape(-1, 1)
+
+        data_for_predictions_df = pd.DataFrame(data_for_predictions)
+        data_for_predictions_df.rename(columns={0: predicted_column_name})
+
+    else:
+        raise TypeError(colorize("""Input data must be in pd.dataframe, pd.series or numpy array. If you use csv or sql data source, its converted automatically,
+                                 but setup csv_full_path. Check config comments fore  more informations..."""))
+
+    data_for_predictions = data_for_predictions.astype(config['dtype'], copy=False)
+
+    return data_for_predictions, data_for_predictions_df, predicted_column_name
+
+
 def keep_corelated_data(data, predicted_column_index=0, threshold=0.5):
     """Remove columns that are not corelated enough to predicted columns.
 
@@ -76,12 +214,12 @@ def remove_outliers(data, predicted_column_index=0, threshold=3):
     #     data = data[abs(data - data.mean()) < threshold * data.std()]
     #     return data
 
-    data_mean = data[predicted_column_index].mean()
-    data_std = data[predicted_column_index].std()
+    data_mean = data[:, predicted_column_index].mean()
+    data_std = data[:, predicted_column_index].std()
 
-    range_array = np.array(range(data.shape[1]))
-    names_to_del = range_array[abs(data[predicted_column_index] - data_mean) > threshold * data_std]
-    data = np.delete(data, names_to_del, axis=1)
+    range_array = np.array(range(data.shape[0]))
+    names_to_del = range_array[abs(data[:, predicted_column_index] - data_mean) > threshold * data_std]
+    data = np.delete(data, names_to_del, axis=0)
 
     return data
 
@@ -102,7 +240,7 @@ def do_difference(data):
         [2, 2, -3]
     """
 
-    diff = np.diff(data)
+    diff = np.diff(data.T).T
 
     return diff
 
@@ -131,12 +269,11 @@ def inverse_difference(differenced_predictions, last_undiff_value):
     return undiff
 
 
-def standardize(data, predicted_column_index=0, used_scaler='standardize'):
+def standardize(data, used_scaler='standardize', predicted_column=0):
     """Standardize or normalize data. More standardize methods available.
 
     Args:
         data (ndarray): Time series data.
-        predicted_column_index (int, optional): Index of column that is predicted. Defaults to 0.
         used_scaler (str, optional): '01' and '-11' means scope from to for normalization.
             'robust' use RobustScaler and 'standard' use StandardScaler - mean is 0 and std is 1. Defaults to 'standardize'.
 
@@ -144,8 +281,6 @@ def standardize(data, predicted_column_index=0, used_scaler='standardize'):
         ndarray: Standardized data.
     """
 
-    from sklearn import preprocessing
-
     scaler = {
         '01': preprocessing.MinMaxScaler(feature_range=(0, 1)),
         '-11': preprocessing.MinMaxScaler(feature_range=(-1, 1)),
@@ -153,9 +288,9 @@ def standardize(data, predicted_column_index=0, used_scaler='standardize'):
         'standardize': preprocessing.StandardScaler()
     }[used_scaler]
 
-    normalized = scaler.fit_transform(data.T).T
+    normalized = scaler.fit_transform(data)
 
-    final_scaler = scaler.fit(data[0].reshape(-1, 1))
+    final_scaler = scaler.fit(data[:, predicted_column].reshape(-1, 1))
 
     return normalized, final_scaler
 
@@ -179,34 +314,33 @@ def split(data, predicts=7, predicted_column_index=0):
         [2, 3]
         [4, 5]
     """
-
-    if isinstance(data, (pd.Series, pd.DataFrame)):
-        train = data.iloc[: -predicts]
-        test = data.iloc[-predicts:]
-        if test.shape[1] > 1:
-            test = test.iloc[:, predicted_column_index]
-
-    elif isinstance(data, np.ndarray):
-
-        if data.ndim == 1:
-            train = data[:(len(data) - predicts)]
-            test = data[-predicts:]
-
-            if predicts > (len(data)):
-                print('To few data, train/test not returned')
-                return ([np.nan], [np.nan] * predicts)
-
-        if predicts > (data.shape[1]):
-            print('To few data, train/test not returned')
-            return ([np.nan], np.array([np.nan] * predicts))
-
-        train = data[:, :-predicts]
-
-        test = data[predicted_column_index, -predicts:]
+    if isinstance(data, pd.DataFrame):
+        train = data.iloc[:-predicts, :]
+        test = data.iloc[-predicts:, predicted_column_index]
+    else:
+        train = data[:-predicts, :]
+        test = data[-predicts:, predicted_column_index]
 
     return train, test
 
 
+def smooth(data, window=101, polynom_order=2):
+    """Smooth data (reduce noise) with Savitzky-Golay filter. For more info on filter check scipy docs.
+
+    Args:
+        data (ndarray): Input data.
+        window (tuple, optional): Length of sliding window. Must be odd.
+        polynom_order - Must be smaller than window.
+
+    Returns:
+        ndarray: Cleaned data with less noise.
+    """
+    for i in range(data.shape[1]):
+        data[:, i] = scipy.signal.savgol_filter(data[:, i], window, polynom_order)
+
+    return data
+
+
 def fitted_power_transform(data, fitted_stdev, mean=None, fragments=10, iterations=5):
     """Function mostly for data postprocessing. Function transforms data, so it will have
     similiar standar deviation, similiar mean if specified. It use Box-Cox power transform in SciPy lib.
@@ -249,129 +383,3 @@ def fitted_power_transform(data, fitted_stdev, mean=None, fragments=10, iteratio
         transformed_results = transformed_results - mean_difference
 
     return transformed_results
-
-
-def smooth(data, filter='savgol', filter_args=(101, 2)):
-    """Smooth data (reduce noise) with using some filter.
-
-    Args:
-        data (ndarray): Input data.
-        filter (str, optional): Used filter. Defaults to 'savgol'.
-        filter_args (tuple, optional): Used filter arguments. Defaults to (101, 2).
-
-    Returns:
-        ndarray: Cleaned data with less noise.
-
-    'savgol' filter means Savitzky-Golay filter. For more info on filter check scipy docs.
-    """
-
-    if filter == 'savgol':
-        filtered = scipy.signal.savgol_filter(data, filter_args[0], filter_args[1])
-
-    return filtered
-
-
-
-def data_consolidation(data):
-
-    ### Pandas dataframe and series ###
-
-    if isinstance(data, pd.Series):
-
-        data = pd.Dataframe(data)
-
-    if isinstance(data, pd.DataFrame):
-        data_for_predictions_df = data.iloc[-config['datalength']:, ]
-
-        if isinstance(config['predicted_column'], str):
-
-            predicted_column_name = config['predicted_column']
-
-            try:
-                predicted_column_index = data_for_predictions_df.columns.get_loc(predicted_column_name)
-            except Exception:
-                raise KeyError(colorize(f"Predicted column name - '{config['predicted_column']}' not found in data. Change in config - 'predicted_column'"))
-
-        else:
-            predicted_column_index = config['predicted_column']
-            predicted_column_name = data_for_predictions_df.columns[predicted_column_index]
-
-
-        if isinstance(data.index, (pd.core.indexes.datetimes.DatetimeIndex, pd._libs.tslibs.timestamps.Timestamp)):
-            config['datetime_index'] = 'index'
-
-        if config['datetime_index'] is not None:
-
-            if config['datetime_index'] == 'index':
-                pass
-
-            elif isinstance(config['datetime_index'], str):
-                try:
-                    data_for_predictions_df.set_index(config['datetime_index'], drop=True, inplace=True)
-                except Exception:
-                    raise KeyError(colorize(f"Datetime name / index from config - '{config['datetime_index']}' not found in data. Change in config - 'datetime_index'"))
-
-            else:
-                data_for_predictions_df.set_index(data_for_predictions_df.columns[config['datetime_index']], drop=True, inplace=True)
-
-            data_for_predictions_df.index = pd.to_datetime(data_for_predictions_df.index)
-
-            if config['freq']:
-                data_for_predictions_df.sort_index(inplace=True)
-                data_for_predictions_df = data_for_predictions_df.resample(config['freq']).sum()
-                data_for_predictions_df = data_for_predictions_df.asfreq(config['freq'], fill_value=0)
-
-            else:
-
-                data_for_predictions_df.index.freq = pd.infer_freq(data_for_predictions_df.index)
-
-                if data_for_predictions_df.index.freq is None:
-                    user_warning("Datetime index was provided from config, but frequency guess failed. Specify 'freq' in config to resample and have equal sampling.")
-                    data_for_predictions_df.reset_index(inplace=True)
-
-        # Make predicted column index 0
-        data_for_predictions_df.insert(0, predicted_column_name, data_for_predictions_df.pop(predicted_column_name))
-
-        if config['other_columns']:
-
-            if config['remove_nans'] == 'any_columns':
-                data_for_predictions_df.dropna(how='any', inplace=True, axis=1)
-
-            data_for_predictions_df = data_for_predictions_df.select_dtypes(include='number')
-            data_for_predictions = data_for_predictions_df.values.T
-
-        else:
-            data_for_predictions = data_for_predictions_df[predicted_column_name].to_frame().values.T
-
-    ### np.ndarray ###
-
-    elif isinstance(data, np.ndarray):
-        data_for_predictions = data
-        predicted_column_name = 'Predicted column'
-
-        if data_for_predictions.ndim == 1:
-            data_for_predictions = data_for_predictions.reshape(1, -1)
-
-        if data_for_predictions.shape[0] > data_for_predictions.shape[1]:
-            data_for_predictions = data_for_predictions.T
-
-        data_for_predictions = data_for_predictions[:, -config['datalength']:]
-
-        # Make predicted column on index 0
-        if config['other_columns'] and config['predicted_column'] != 0 and data_for_predictions.shape[0] != 1:
-            data_for_predictions[[0, config['predicted_column']], :] = data_for_predictions[[config['predicted_column'], 0], :]
-
-        if not config['other_columns']:
-            data_for_predictions = data_for_predictions[0].reshape(1, -1)
-
-    else:
-        raise TypeError(colorize("""Input data must be in pd.dataframe, pd.series or numpy array. If you use csv or sql data source, its converted automatically,
-                                 but setup csv_full_path. Check config comments fore  more informations..."""))
-
-    data_for_predictions = data_for_predictions.astype(config['dtype'], copy=False)
-
-    if 'data_for_predictions_df' not in locals():
-        data_for_predictions_df = pd.DataFrame(data_for_predictions.T)
-        data_for_predictions_df.rename(columns={0: predicted_column_name})
-
-    return data_for_predictions, data_for_predictions_df, predicted_column_name
